@@ -17,7 +17,11 @@
 #include <QModelIndex>
 #include <QStandardItem>
 #include <QStandardItemModel>
-#include <QMaemo5InformationBox>
+#ifdef Q_WS_MAEMO_5
+    #include <QMaemo5InformationBox>
+#else
+    #include "Banner.h"
+#endif
 #include <qspotify_src/spotifysession.h>
 #include <qspotify_src/imagecontainer.h>
 #include <qspotify_src/album.h>
