@@ -10,7 +10,7 @@ static void libplayback_state_request_handler(pb_playback_t   *pb,
                                               void            *data)
 {
     //playback state change request received via libplayback
-    pb_playback_req_completed(pb, req);
+    //pb_playback_req_completed(pb, req);
     OssoWrapper::m_pStaticOssoWrapper->playbackStateRequestHandlerCallback(req_state);
 }
 
@@ -48,12 +48,12 @@ OssoWrapper::OssoWrapper(const QString& strAppName, const QString& strAppVersion
 OssoWrapper::~OssoWrapper()
 {
     //deinitialise / free the osso context
-#ifdef Q_WS_MAEMO_5
+//#ifdef Q_WS_MAEMO_5
     if(m_pPlayback)
         pb_playback_destroy(m_pPlayback);
     if(m_pOssoContext)
         osso_deinitialize(m_pOssoContext);
-#endif
+//#endif
 }
 
 #ifdef Q_WS_MAEMO_5
@@ -88,7 +88,7 @@ bool OssoWrapper::initOssoPlayback(const QString& audioStream)
                                         PB_STATE_STOP,
                                         (PBStateRequest)libplayback_state_request_handler,
                                         NULL);
-        if(m_pPlayback)
+        if(m_pPlayback && audioStream != "")
         { //set the id of stream that handles the playback (e.g., id of pulseaudio stream)
             streamID = audioStream.toLatin1();
             pb_playback_set_stream(m_pPlayback, streamID.data());
@@ -124,7 +124,6 @@ void OssoWrapper::playbackStateReplyCallback(enum pb_state_e grantedState, const
     {
         strReason = reason;
     }
-
     emit playbackStateReply(grantedState, strReason);
 }
 
