@@ -6,7 +6,9 @@ PickSelectorAction::PickSelectorAction(QObject *parent)
     : QWidgetAction(parent)
 {
 
+#ifdef Q_WS_MAEMO_5
     m_pListModel = new QStringListModel(this);
+#endif
     m_currSelection = 0;
 }
 
@@ -18,6 +20,7 @@ void PickSelectorAction::setText(const QString& txt)
 
 QWidget * PickSelectorAction::createWidget(QWidget *parent)
 {
+#ifdef Q_WS_MAEMO_5
     QMaemo5ListPickSelector *selector = new QMaemo5ListPickSelector(parent);
     selector->setModel(m_pListModel);
     selector->setCurrentIndex(m_currSelection);
@@ -30,13 +33,24 @@ QWidget * PickSelectorAction::createWidget(QWidget *parent)
     connect(selector, SIGNAL(selected(const QString &)), this, SLOT(selectionChanged(const QString &)));
 
     return valueButton;
+#else
+    QComboBox *pCombo = new QComboBox(parent);
+
+    pCombo->addItems(m_List);
+
+    connect(pCombo, SIGNAL(currentIndexChanged(QString)), this, SLOT(selectionChanged(const QString &)));
+
+    return pCombo;
+#endif
 }
 
 void PickSelectorAction::populateListModel(const QStringList& list)
 {
     //populate the underlying list model
      m_List = list;
+#ifdef Q_WS_MAEMO_5
      m_pListModel->setStringList(list);
+#endif
 }
 
 void PickSelectorAction::selectionChanged(const QString& selection)
