@@ -16,6 +16,7 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, DBusWrapper
 
     m_pSession = pSession; //set the Spotify session instance
     m_playing = false; //set initial playback state
+    m_playbackStateChangeReq = true; //on initial playback start, request state change
     m_tokenLost = false; //set inital token state
     m_userInitiatedPause = false;
     m_pauseOnHsetUnplugged = false;
@@ -46,6 +47,7 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, DBusWrapper
     m_currQueueBuffPos = 0;
     m_shuffle = false;
     m_shuffleStateChanged = false;
+    m_queueOffline = false;
 
     //define slider used for displaying buffering and track progress
     m_currSliderWidth = SLIDER_WIDTH_LANDSCAPE;
@@ -77,7 +79,7 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, DBusWrapper
     setupMenubar(); //setup the view menubar
 
     //set up signal and slot connections
-    connect(m_pSession,SIGNAL(trackBufferingAmountUpdated(qint32)),SLOT(OnTrackBufferedAmountUpdated(qint32)));
+    connect(m_pSession,SIGNAL(trackBufferingAmountUpdated(quint32)),SLOT(OnTrackBufferedAmountUpdated(quint32)));
     connect(m_pSession,SIGNAL(playbackPositionUpdated(qint64)),SLOT(OnPlaybackPositionUpdated(qint64)));
     connect(m_pSession,SIGNAL(albumBrowserReady(Spotify::AlbumBrowser*,qint32)),SLOT(OnAlbumBrowseReady(Spotify::AlbumBrowser*,qint32)));
     connect(m_pSession,SIGNAL(playing(bool)),SLOT(OnPlayingState(bool)));
@@ -171,6 +173,18 @@ QueueView::~QueueView()
 {
 }
 
+void QueueView::setQueueOffline(bool offline)
+{
+    //set the queue offline state
+    m_queueOffline = offline;
+}
+
+bool QueueView::isQueueOffline()
+{
+    //returns true in case the tracks in the current queue are available offline; otherwise false
+    return m_queueOffline;
+}
+
 void QueueView::setupContextMenu()
 {
     //set up the listview context menu
@@ -518,7 +532,10 @@ void QueueView::playTrack(Spotify::Track* track)
     if(m_playbackStateChangeReq)
     { //ask for state change
         m_playbackStateChangeReq = false;
-        m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_PLAY);
+        if(m_pOssoWrapper)
+        {
+            m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_PLAY);
+        }
     }
 #endif
     m_currTrackScrobbled = false;
@@ -565,7 +582,7 @@ void QueueView::playTrack(Spotify::Track* track)
 #endif
 }
 
-void QueueView::OnTrackBufferedAmountUpdated(qint32 bufferedAmount)
+void QueueView::OnTrackBufferedAmountUpdated(quint32 bufferedAmount)
 {
     //Amount of buffered of the currently loaded / playing track has been updated
     int currPos;
@@ -580,7 +597,6 @@ void QueueView::OnTrackBufferedAmountUpdated(qint32 bufferedAmount)
         {
             currPos = (bufferedAmount*m_currSliderWidth) / (m_currTrackDuration*1000); //current track has partly been buffered
         }
-
         m_pProgressSlider->setPos1(currPos); //set curr. slider position
     }
 }
@@ -639,7 +655,8 @@ void QueueView::OnPauseResumeToggle()
         if(m_playbackStateChangeReq)
         { //ask for state change
             m_playbackStateChangeReq = false;
-            m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_PLAY); //notify via libplayback that we are entering playing state
+            if(m_pOssoWrapper)
+                m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_PLAY); //notify via libplayback that we are entering playing state
         }
 #endif
         if(!m_PauseResumeBtn.isChecked()) //entering paused state
