@@ -71,6 +71,10 @@ public:
 
     void setHideCoverart(bool hide); //set the album coverart display state (based upon hide parameter)
 
+    void setQueueOffline(bool offline); //set the queue offline state
+
+    bool isQueueOffline(); //returns true in case the tracks in the current queue are available offline; otherwise false
+
 
 protected:
 
@@ -162,6 +166,8 @@ private:
 
     bool m_userInitiatedPause; //TRUE in case playback has been paused by user (and not automatically by system)
 
+    bool m_queueOffline; //TRUE in case tracks in queue are available offline
+
     QTime m_lastTimeTrackActivated; //timestamp when user has last activated a track in the listview (used for i.e., preventing rapid double-tapping)
 
     void addTracks(QList<Spotify::Track*> trackList); //add tracks from specified tracklist to main listview
@@ -189,7 +195,7 @@ private slots:
     void OnTrackActivated(QModelIndex index);
     void OnPauseResumeToggle();
     void OnShuffleToggle();
-    void OnTrackBufferedAmountUpdated(qint32 bufferedAmount);
+    void OnTrackBufferedAmountUpdated(quint32 bufferedAmount);
     void OnPlaybackPositionUpdated(qint64 playbackPos);
     void OnAlbumCoverLoaded();
     void OnTrackPlaybackFinished();
