@@ -278,7 +278,7 @@ void TrackView::setPlaylist(Spotify::Playlist* pPlaylist)
 
             setWindowTitle(pPlaylist->getName());
 
-            m_pSortByAct->setCurrentSelection(MOST_POPULAR_DESC); //set sorting to Most Popular (descending) order
+            m_pSortByAct->setCurrentSelection(ORIGINAL); //set sorting to Playlist order
 
             m_pPlaylist->restoreOrignalCollection();
 
