@@ -275,7 +275,7 @@ void MainWindow::showAboutDialog()
     m_AboutDlg.setTopIcon("/usr/share/icons/hicolor/64x64/apps/qspot.png");
     m_AboutDlg.setBottomIcon("/opt/qspot/images/spotify-core-logo.png"); //powered by Spotify(R) Core
     m_AboutDlg.setText(tr("An open-source Qt-based Spotify client for N900/Maemo5.\n"
-                        "(C) 2011 Andreas Enbacka and The QSpot Team.\n\n"
+                        "(C) 2012 Andreas Enbacka and The QSpot Team.\n\n"
                         "Special thanks to Markus for assistance with the graphical design and layout, "
                         "and to Tomi, Florian, Benno and Nicolas for the translations.\n\n") +
                         tr("Go online within") + " " + strOfflineTimeLeftFormatted);
@@ -661,7 +661,6 @@ void MainWindow::updatePlaylistModel()
 {
     //update the listmodel from underlying playlist instances
 
-
     //load delegate icons
     QPixmap iconMap;
     iconMap.load("/opt/qspot/images/icon-type-list.png"); //load playlist type icon from file
@@ -678,8 +677,10 @@ void MainWindow::updatePlaylistModel()
     for(qint32 pos=0; pos < m_Playlists.size(); pos++)
     {
         Spotify::Playlist* pl = m_Playlists.at(pos);
-        if(pl->getOfflineStatus() != Spotify::Available && m_pSession->isOfflineMode())
-        {//we are currently in offline mode, and the playlist has not been synced for offline usage
+        if((pl->getOfflineStatus() != Spotify::Available && m_pSession->isOfflineMode())||
+            (pl->getName()=="" && pl->getNumTracks()==0))
+        {//we are currently in offline mode, and the playlist has not been synced for offline usage;
+            //we also skip playlists that indicate start / stop of folder (todo: implement folder support)
             continue; //skip list (do not display list in the listview)
         }
         else
@@ -1046,7 +1047,7 @@ void MainWindow::OnContextMenuRequested(QPoint pnt)
 
     if(m_pPlaylistView->currentIndex().row()>=0)
     {
-        Spotify::Playlist* pPlaylist = m_Playlists.at(m_pPlaylistView->currentIndex().row());
+        Spotify::Playlist* pPlaylist = m_Playlists.at(m_pPlaylistView->currentIndex().data(ListViewDelegate::customDataRole).toInt());
         if(pPlaylist)
         {
             if(pPlaylist->getOfflineStatus()!=Spotify::Available)
