@@ -455,7 +455,7 @@ void Spotify::Session::OnProcessThreadEvents()
 void Spotify::Session::login( QString username, QString password, bool storeCredentials )
 {
     // Request to login to Spotify with supplied credentials (remember login credentials in case storeCredentials set)
-    sp_session_login( m_session, username.toUtf8(), password.toUtf8(), storeCredentials );
+    sp_session_login( m_session, username.toUtf8(), password.toUtf8(), storeCredentials);
 }
 
 Spotify::Error Spotify::Session::relogin()
@@ -663,9 +663,15 @@ Spotify::Error Spotify::Session::search( const QString& query, const int trackOf
                                          const int artistCount, void* userdata )
 {
     Spotify::Error error;
+    //sp_search_type type;
+
+    //if(suggestedSearch)
+      //  type=SP_SEARCH_SUGGEST;
+    //else
+      //  type=SP_SEARCH_STANDARD;
+
     sp_search* search = sp_search_create( m_session, query.toUtf8().data(), trackOffset, trackCount,
-                                          albumOffset, albumCount, artistOffset, artistCount,
-                                          &searchCompleteCallback, userdata );
+                                          albumOffset, albumCount, artistOffset, artistCount, &searchCompleteCallback, userdata );
 
     Spotify::Search* s = new Spotify::Search(m_session, search, this );
     m_searchHash.insert( search, s );
