@@ -132,6 +132,9 @@ bool Spotify::Track::load()
         else
             m_isOffline = false;
 
+        //Set track starred status
+        m_isStarred = sp_track_is_starred(m_session, m_track);
+
         m_loaded = true;
         emit loaded();
     }
